aboutsummaryrefslogtreecommitdiff
path: root/lib/curl_sasl_gssapi.c
diff options
context:
space:
mode:
Diffstat (limited to 'lib/curl_sasl_gssapi.c')
-rw-r--r--lib/curl_sasl_gssapi.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/curl_sasl_gssapi.c b/lib/curl_sasl_gssapi.c
index 3c6f3ce32..5ff893934 100644
--- a/lib/curl_sasl_gssapi.c
+++ b/lib/curl_sasl_gssapi.c
@@ -43,19 +43,19 @@
/*
* Curl_sasl_build_gssapi_spn()
*
* This is used to build a SPN string in the format service@host.
*
* Parameters:
*
* serivce [in] - The service type such as www, smtp, pop or imap.
* host [in] - The host name or realm.
*
* Returns a pointer to the newly allocated SPN.
*/
-char *Curl_sasl_build_gssapi_spn(const char *service, const char *host)
+char *Curl_sasl_build_gssapi_spn(const char *service, const char *instance)
{
/* Generate and return our SPN */
- return aprintf("%s@%s", service, host);
+ return aprintf("%s@%s", service, instance);
}
/*
@@ -43,19 +43,19 @@
* Curl_sasl_build_gssapi_spn()
*
-* This is used to build a SPN string in the format service@host.
+* This is used to build a SPN string in the format service@instance.
*
* Parameters:
@@ -43,19 +43,19 @@
* Parameters:
*
-* serivce [in] - The service type such as www, smtp, pop or imap.
-* host [in] - The host name or realm.
+* service [in] - The service type such as www, smtp, pop or imap.
+* instance [in] - The host name or realm.
*
* Returns a pointer to the newly allocated SPN.